@@ -12,13 +12,17 @@ PREPROCESSORS_TAG = 'preprocessor'
 POSTPROCESSORS_TAG = 'postprocessor'
 FUNCTIONS_TAG = 'functions'
 CVAT_INFO_TAG = 'cvat-info'
+CVAT_PREPROCESSORS_TAG = 'cvat-preprocessor'
+CVAT_POSTPROCESSORS_TAG = 'cvat-postprocessor'
 
 SUPPORTED_TAGS = [
     REQUIREMENTS_TAG,
     PREPROCESSORS_TAG,
     POSTPROCESSORS_TAG,
     FUNCTIONS_TAG,
-    CVAT_INFO_TAG
+    CVAT_INFO_TAG,
+    CVAT_PREPROCESSORS_TAG,
+    CVAT_POSTPROCESSORS_TAG
 ]
 
 class NotebookProcessor():
@@ -44,6 +48,8 @@ class NotebookProcessor():
         postprocessor_block = list()
         functions_block = list()
         cvat_info_block = list()
+        cvat_preprocessor_block = list()
+        cvat_postprocessor_block = list()
 
         for c in self.notebook.cells:
             if c.cell_type != "code":
@@ -68,6 +74,12 @@ class NotebookProcessor():
             elif CVAT_INFO_TAG == tag:
                 cvat_info_block.append(c.source)
                 continue
+            elif CVAT_PREPROCESSORS_TAG == tag:
+                cvat_preprocessor_block.append(c.source)
+                continue
+            elif CVAT_POSTPROCESSORS_TAG == tag:
+                cvat_postprocessor_block.append(c.source)
+                continue
             else:
                 continue
         return {
@@ -75,7 +87,9 @@ class NotebookProcessor():
             PREPROCESSORS_TAG: preprocessor_block,
             POSTPROCESSORS_TAG: postprocessor_block,
             FUNCTIONS_TAG: functions_block,
-            CVAT_INFO_TAG: cvat_info_block
+            CVAT_INFO_TAG: cvat_info_block,
+            CVAT_PREPROCESSORS_TAG: cvat_preprocessor_block,
+            CVAT_POSTPROCESSORS_TAG: cvat_postprocessor_block
         }
 
     def get_cell_transformer_tag(self, metadata):
